gensim: Support
Description: Efficient topic modelling of text semantics in Python.

#

### Get Expert Help

• machine learning, NLP, data mining

• custom SW design, development, optimizations

• tech trainings & IT consulting

Support

# Support

## Open source support

The main communication channel is the gensim mailing list. This is the preferred way to ask for help, report problems and share insights with the community. Newbie questions are perfectly fine, just make sure you’ve read the tutorials.

I discourage sending private emails, because the mailing list serves as a knowledge base for all gensim users, cutting maintenance efforts needed for support. If you feel your problem is too special, data too sensitive, technical scope too demanding, see the “business” section below.

When posting on the mailing list, please try to include all relevant information, such as what it is you are trying to achieve, what went wrong, relevant gensim logs etc.

FAQ and some useful snippets of code are maintained on GitHub: https://github.com/piskvorky/gensim/wiki/Recipes-&-FAQ.

You can also try asking on StackOverflow, using the gensim tag.

## Developer support

Developers who tweak gensim internals are encouraged to report issues at the GitHub issue tracker. Note that this is not a medium for discussions or asking open-ended questions; please use the mailing list for that.

## Business support

I also run a consulting business for data mining and information retrieval solutions, radimrehurek.com.

In case you need SLA-based support, design validation, technical training or custom system development, get in touch for a commercial quote.